@@ -1,15 +1,13 @@
-import numpy as np
-from sympy.parsing.sympy_parser import parse_expr
-import sympy as sp
 import itertools
-from six import string_types
-from pandas import DataFrame, Series
-
 from collections import OrderedDict
 
-from matminer.featurizers.base import BaseFeaturizer
+import numpy as np
+import sympy as sp
+from pandas import DataFrame, Series
 from sklearn.exceptions import NotFittedError
+from sympy.parsing.sympy_parser import parse_expr
 
+from matminer.featurizers.base import BaseFeaturizer
 
 # Default expressions to include in function featurizer
 default_exps = [
@@ -44,6 +42,18 @@ class FunctionFeaturizer(BaseFeaturizer):
     (e. g. with feature labels), substitution, and elimination
     of symbolic redundancy, which sympy is well-suited for.
 
+
+    Note original feature names in the resulting feature set
+    will have their sympy-illegal characters substituted with
+    underscores. For example:
+
+    "exp(-MagpieData_avg_dev_NfValence)/sqrt(MagpieData_range_Number)"
+
+    Where the original feature names were
+
+    "MagpieData avg_dev NfValence"  and "MagpieData range Number"
+
+
     Args:
         expressions ([str]): list of sympy-parseable expressions
             representing a function of a single variable x, e. g.
@@ -64,6 +74,8 @@ class FunctionFeaturizer(BaseFeaturizer):
             defaults to False
     """
 
+    ILLEGAL_CHARACTERS = ["|", " ", "/", "\\", "?", "@", "#", "$", "%"]
+
     def __init__(
         self,
         expressions=None,
@@ -154,9 +166,17 @@ class FunctionFeaturizer(BaseFeaturizer):
             List of string expressions generated by substitution of
             variable names into functions
         """
-        if isinstance(input_variable_names, string_types):
+        if isinstance(input_variable_names, str):
             input_variable_names = [input_variable_names]
+
         postprocess = sp.latex if self.latexify_labels else str
+
+        input_variable_names_clean = [None] * len(input_variable_names)
+        for i, n in enumerate(input_variable_names):
+            for ic in self.ILLEGAL_CHARACTERS:
+                n = n.replace(ic, "_")
+            input_variable_names_clean[i] = n
+
         return list(self._exp_iter(*input_variable_names, postprocess=postprocess))
 
     def _exp_iter(self, *args, postprocess=None):
@@ -167,7 +187,7 @@ class FunctionFeaturizer(BaseFeaturizer):
         replicated code in featurize and feature labels
 
         Args:
-            *args: args to loop over combinations and substitions for
+            *args: args to loop over combinations and substitutions for
             postprocess (function): postprocessing function, e. g.
                 to cast to another type, float, str
 
@@ -178,7 +198,7 @@ class FunctionFeaturizer(BaseFeaturizer):
         postprocess = postprocess or (lambda x: x)
         for n in range(1, self.multi_feature_depth + 1):
             for arg_combo in itertools.combinations(args, n):
-                subs_dict = {"x{}".format(m): arg for m, arg in enumerate(arg_combo)}
+                subs_dict = {f"x{m}": arg for m, arg in enumerate(arg_combo)}
                 for exp in self.exp_dict[n]:
                     # TODO: this is a workaround for the problem
                     # TODO: postprocessing functional incompatility,
@@ -228,12 +248,12 @@ def generate_expressions_combinations(expressions, combo_depth=2, combo_function
         list of unique non-trivial expressions for featurization
             of inputs
     """
-    # Convert to array for simpler subsitution
+    # Convert to array for simpler substitution
     exp_array = sp.Array([parse_expr(exp) for exp in expressions])
 
     # Generate all of the combinations
     combo_exps = []
-    all_arrays = [exp_array.subs({"x": "x{}".format(n)}) for n in range(combo_depth)]
+    all_arrays = [exp_array.subs({"x": f"x{n}"}) for n in range(combo_depth)]
     # Get all sets of expressions
     for exp_set in itertools.product(*all_arrays):
         # Get all permutations of each set
